@@ -238,8 +238,9 @@ class Session(object):
             return
 
         CORE.info('session %r timed out' % (self.session_id,))
-        self.sessions.pop(self.session_id, None)
+        self.expire(self.session_id)
         self.on_logout()
+        self.processes.timed_out()
         return False
 
     def reset_timeout(self):
@@ -307,7 +308,6 @@ class IACLs(object):
             return ACLs()
         else:
             return LDAP_ACLs(self.session.user.username, ucr['ldap/base'])
-            lo, po = get_machine_connection(write=False)
 
     def is_command_allowed(self, command, options, flavor):
         if not isinstance(options, dict):
@@ -389,6 +389,11 @@ class Processes(object):
 
         return processes[module_name]
 
+    def timed_out(self):
+        CORE.warn('Closing all sockets to currently opened module processes for this session.')
+        for proc in self.__processes.values():
+            proc.abort()
+
     def stop_process(self, module_name):
         proc = self.processes(module_name).pop(module_name, None)
         if proc:
